==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/pt_BR.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Equipes",
    "You created the team {circle}" : "Você criou a equipe {circle}",
    "{author} created the team {circle}" : "{author} criou a equipe {circle}",
    "You deleted {circle}" : "Você excluiu {circle}",
    "{author} deleted {circle}" : "{author} excluiu {circle}",
    "You made {member} join {circle}" : "Você fez com que {member} se juntasse a {circle}",
    "{author} made {member} join {circle}" : "{author} fez com que {member} se juntasse a {circle}",
    "You added team {member} as member to {circle}" : "Você adicionou a equipe {member} como membro de {circle}",
    "{author} added team {member} as member to {circle}" : "{author} adicionou a equipe {member} como membro de {circle}",
    "You made {member} leave {circle}" : "Você fez {member} sair de {circle}",
    "{author} made {member} leave {circle}" : "{author} fez {member} sair de {circle}",
    "You removed {member} from {circle}" : "Você excluiu {member} de {circle}",
    "{author} removed {member} from {circle}" : "{author} excluiu {member} de {circle}",
    "You joined {circle}" : "Você juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se à {circle}",
    "You accepted the invitation to join {circle}" : "Você aceitou o convite para juntar-se à {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} aceitou o convite para juntar-se à {circle}",
    "You added {member} as member to {circle}" : "Você adicionou {member} como membro de {circle}",
    "You have been added as member to {circle} by {author}" : "Você foi adicionado como membro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} foi adicionado como membro de {circle} por {author}",
    "You added {external} to {circle}" : "Você adicionou {external} à {circle}",
    "{external} has been added to {circle} by {author}" : "{external} foi adicionado à {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Você aceitou a solicitação de {member} para juntar-se à {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Sua solicitação para juntar-se à {circle} foi aceita por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "A solicitação de {member} para juntar-se à {circle} foi aceita por {author}",
    "You left {circle}" : "Você saiu de {circle}",
    "{member} left {circle}" : "{member} deixou {circle}",
    "You declined the invitation to join {circle}" : "Você recusou o convite para juntar-se a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} recusou o convite para juntar-se a {circle}",
    "You cancelled your request to join {circle}" : "Você cancelou sua solicitação para juntar-se a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} cancelou uma solicitação para juntar-se a {circle}",
    "You have been removed from {circle} by {author}" : "Você foi removido de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} foi removido de {circle} por {author}",
    "You removed {external} from {circle}" : "Você removeu {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} foi removido de {circle} por {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Você cancelou o convite de {member} para juntar-se a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Seu convite para juntar-se a {circle} foi cancelado por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelou o convite de {member} para juntar-se a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Você dispensou a solicitação de {member} para entrar em {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Sua solicitação para entrar em {circle} foi dispensada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "A solicitação de {member} para entrar em {circle} foi dispensada por {author}",
    "You invited {member} to join {circle}" : "Você convidou {member} a juntar-se à {circle}",
    "You have been invited to join {circle} by {author}" : "Você foi convidado a juntar-se à {circle} por {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} foi convidado a juntar-se à {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Você mudou o nível de {member} em {circle} para %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} mudou seu nível em {circle} para %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} mudou o nível de {member} em {circle} para %1$s",
    "You sent a request to join {circle}" : "Você solicitou juntar-se à {circle}",
    "{member} sent a request to join {circle}" : "{member} solicitou juntar-se à {circle}",
    "You are the new owner of {circle}" : "Você é o novo proprietário de {circle}",
    "{member} is the new owner of {circle}" : "{member} é o novo proprietário de {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Em eventos que acontecem em uma <strong>equipe</strong> da qual você é membro",
    "Any important event in a <strong>team</strong> you are moderating" : "Qualquer evento importante em uma <strong>equipe</strong> que você está moderando",
    "On global events happening in any <strong>team</strong>" : "Em eventos globais que acontecem em qualquer <strong>equipe</strong>",
    "Single" : "Único",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Visible" : "Visível",
    "Open" : "Abrir",
    "Invite" : "Convidar",
    "Join request" : "Solicitação de adesão",
    "Friends" : "Amigos",
    "Password protected" : "Protegido por senha",
    "No Owner" : "Sem proprietário",
    "Hidden" : "Oculto",
    "Backend" : "Processo Interno",
    "Local" : "Local",
    "Root" : "Raiz",
    "Team invite" : "Convite de equipe",
    "Federated" : "Federado",
    "Mount point" : "Ponto de montagem",
    "Nextcloud Account" : "Conta Nextcloud",
    "Nextcloud Group" : "Grupo Nextcloud",
    "Email address" : "Endereço de e-mail",
    "Contact" : "Contato",
    "Team" : "Equipe",
    "Nextcloud App" : "Aplicativo Nextcloud",
    "Teams App" : "Aplicativo Equipes",
    "Admin Command Line" : "Linha de Comando do Administrador",
    "Member" : "Membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s compartilhou »%s« com você.",
    "%s shared »%s« with \"%s\"." : "%s compartilhou »%s« com \"%s\".",
    "%s on %s" : "%s em %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou »%2$s« com você.\nVocê já deve ter recebido um e-mail separado com um link para acessar.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou »%2$s« com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
    "Password to access »%1$s« shared to you by %2$s" : "Senha para acessar »%1$s« compartilhado com você por %2$s",
    "Password to access »%s«" : "Senha para acessar »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte senha:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartilhou vários arquivos com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-los.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartilhou vários arquivos com você. Você já deve ter recebido um e-mail separado com um link para acessá-los.",
    "Password to access files shared to you by %1$s" : "Senha para acessar os arquivos compartilhados com você por %1$s",
    "Password to access files" : "Senha para acessar arquivos",
    "%s shared multiple files with \"%s\"." : "%s compartilhou vários arquivos com \"%s\".",
    "%s shared multiple files with you." : "%s compartilhou vários arquivos com você. ",
    "Boot up" : "Inicializar",
    "Nextcloud Initialization" : "Inicialização do Nextcloud",
    "Circles App Initialization" : "Inicialização do Aplicativo Círculos",
    "Fresh installation status" : "Novo status de instalação",
    "Building Local Database" : "Construindo banco de dados local",
    "Testing Basic Circle Creation" : "Teste básico de criação de círculo",
    "Adding local users and moderators" : "Adicionando usuários locais e moderadores",
    "Show all teams" : "Mostrar todas as equipes",
    "Create a new team" : "Criar uma nova equipe",
    "Files" : "Arquivos",
    "This feature is not available for personal circles" : "Este recurso não está disponível para círculos pessoais",
    "The team is not federated" : "A equipe não é federada",
    "You cannot join this team" : "Você não pode entrar nesta equipe",
    "This member is not a moderator" : "Este membro não é moderador",
    "Insufficient privileges" : "Permissões insuficientes",
    "This member does not exist" : "Este membro não existe",
    "This member is the owner of the team" : "Este membro é o proprietário da equipe",
    "Level cannot be changed for this type of member" : "O nível não pode ser mudado para este tipo de usuário",
    "You are already a member of this circle" : "Você já é membro deste círculo",
    "You have been blocked from this circle" : "Você foi bloqueado neste círculo",
    "The account is already a member of this circle" : "A conta já é membro deste círculo",
    "The account has already been invited into this circle" : "A conta já foi convidada para este círculo",
    "%s (Team owned by %s)" : "%s (Equipe de propriedade de %s)",
    "You are now a member of the Team \"%2$s\"" : "Agora você é um membro da Equipe \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Você foi convidado por %1$s para fazer parte da equipe \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s enviou uma solicitação para ser um membro da Equipe \"%2$s\"",
    "Accept" : "Aceitar",
    "Refuse" : "Recusar",
    "Leave the team" : "Deixar a equipe",
    "%s" : "%s",
    "Personal team" : "Equipe pessoal",
    "%s owned by %s" : "%s propriedade de %s",
    "You have no permission to create a new team" : "Você não tem permissão para criar uma nova equipe",
    "%s shared a file with \"%s\"." : "%s compartilhou um arquivo com \"%s\".",
    "%s shared a file with you." : "%s compartilhou um arquivo com você.",
    "%1$s shared %2$s with %3$s" : "%1$s compartilhou %2$s com %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s compartilhou %2$s com \"%3$s\"",
    "Open %s" : "Abrir %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou algum conteúdo com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-lo.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou algum conteúdo com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
    "Password to access content shared with you by %1$s" : "Senha para acessar o conteúdo compartilhado com você por %1$s",
    "Password to access content" : "Senha para acessar o conteúdo",
    "This item is already shared with this team" : "Este item já está compartilhado com esta equipe",
    "Bring cloud-users closer together." : "Reúna os usuários da nuvem.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "O Equipes permite que as pessoas criem seus próprios grupos de pessoas/colegas/amigos. \nEsses grupos de pessoas podem então ser usados ​​por qualquer outro aplicativo para fins de compartilhamento.",
    "Failed to load teams" : "Falha ao carregar equipes",
    "Try again" : "Tentar novamente",
    "No teams found" : "Nenhuma equipe encontrada",
    "Join or create teams to see them here." : "Junte-se ou crie equipes para vê-las aqui.",
    "Create your first team" : "Crie sua primeira equipe",
    "Loading…" : "Carregando…",
    "More teams" : "Mais equipes",
    "No files in here" : "Nenhum arquivo aqui",
    "No entries found in this folder" : "Sem entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "Teams' files" : "Arquivos das equipes",
    "Select team to filter by" : "Selecione uma equipe para filtrar",
    "Please select teams to filter by" : "Selecione equipes para filtrar",
    "No files found for the selected teams" : "Nenhum arquivo encontrado para as equipes selecionadas",
    "Shared to Circles" : "Compartilhado com Círculos",
    "Circle" : "Círculo"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/pt_BR.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Você criou a equipe {circle}",
    "{author} created the team {circle}" : "{author} criou a equipe {circle}",
    "You deleted {circle}" : "Você excluiu {circle}",
    "{author} deleted {circle}" : "{author} excluiu {circle}",
    "You made {member} join {circle}" : "Você fez com que {member} se juntasse a {circle}",
    "{author} made {member} join {circle}" : "{author} fez com que {member} se juntasse a {circle}",
    "You added team {member} as member to {circle}" : "Você adicionou a equipe {member} como membro de {circle}",
    "{author} added team {member} as member to {circle}" : "{author} adicionou a equipe {member} como membro de {circle}",
    "You made {member} leave {circle}" : "Você fez {member} sair de {circle}",
    "{author} made {member} leave {circle}" : "{author} fez {member} sair de {circle}",
    "You removed {member} from {circle}" : "Você excluiu {member} de {circle}",
    "{author} removed {member} from {circle}" : "{author} excluiu {member} de {circle}",
    "You joined {circle}" : "Você juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se à {circle}",
    "You accepted the invitation to join {circle}" : "Você aceitou o convite para juntar-se à {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} aceitou o convite para juntar-se à {circle}",
    "You added {member} as member to {circle}" : "Você adicionou {member} como membro de {circle}",
    "You have been added as member to {circle} by {author}" : "Você foi adicionado como membro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} foi adicionado como membro de {circle} por {author}",
    "You added {external} to {circle}" : "Você adicionou {external} à {circle}",
    "{external} has been added to {circle} by {author}" : "{external} foi adicionado à {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Você aceitou a solicitação de {member} para juntar-se à {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Sua solicitação para juntar-se à {circle} foi aceita por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "A solicitação de {member} para juntar-se à {circle} foi aceita por {author}",
    "You left {circle}" : "Você saiu de {circle}",
    "{member} left {circle}" : "{member} deixou {circle}",
    "You declined the invitation to join {circle}" : "Você recusou o convite para juntar-se a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} recusou o convite para juntar-se a {circle}",
    "You cancelled your request to join {circle}" : "Você cancelou sua solicitação para juntar-se a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} cancelou uma solicitação para juntar-se a {circle}",
    "You have been removed from {circle} by {author}" : "Você foi removido de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} foi removido de {circle} por {author}",
    "You removed {external} from {circle}" : "Você removeu {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} foi removido de {circle} por {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Você cancelou o convite de {member} para juntar-se a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Seu convite para juntar-se a {circle} foi cancelado por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelou o convite de {member} para juntar-se a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Você dispensou a solicitação de {member} para entrar em {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Sua solicitação para entrar em {circle} foi dispensada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "A solicitação de {member} para entrar em {circle} foi dispensada por {author}",
    "You invited {member} to join {circle}" : "Você convidou {member} a juntar-se à {circle}",
    "You have been invited to join {circle} by {author}" : "Você foi convidado a juntar-se à {circle} por {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} foi convidado a juntar-se à {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Você mudou o nível de {member} em {circle} para %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} mudou seu nível em {circle} para %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} mudou o nível de {member} em {circle} para %1$s",
    "You sent a request to join {circle}" : "Você solicitou juntar-se à {circle}",
    "{member} sent a request to join {circle}" : "{member} solicitou juntar-se à {circle}",
    "You are the new owner of {circle}" : "Você é o novo proprietário de {circle}",
    "{member} is the new owner of {circle}" : "{member} é o novo proprietário de {circle}",
    "Teams" : "Equipes",
    "On events happening in a <strong>team</strong> of which you are a member" : "Em eventos que acontecem em uma <strong>equipe</strong> da qual você é membro",
    "Any important event in a <strong>team</strong> you are moderating" : "Qualquer evento importante em uma <strong>equipe</strong> que você está moderando",
    "On global events happening in any <strong>team</strong>" : "Em eventos globais que acontecem em qualquer <strong>equipe</strong>",
    "Single" : "Único",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Visible" : "Visível",
    "Open" : "Abrir",
    "Invite" : "Convidar",
    "Join request" : "Solicitação de adesão",
    "Friends" : "Amigos",
    "Password protected" : "Protegido por senha",
    "No Owner" : "Sem proprietário",
    "Hidden" : "Oculto",
    "Backend" : "Processo Interno",
    "Local" : "Local",
    "Root" : "Raiz",
    "Team invite" : "Convite de equipe",
    "Federated" : "Federado",
    "Mount point" : "Ponto de montagem",
    "Nextcloud Account" : "Conta Nextcloud",
    "Nextcloud Group" : "Grupo Nextcloud",
    "Email address" : "Endereço de e-mail",
    "Contact" : "Contato",
    "Team" : "Equipe",
    "Nextcloud App" : "Aplicativo Nextcloud",
    "Teams App" : "Aplicativo Equipes",
    "Admin Command Line" : "Linha de Comando do Administrador",
    "Member" : "Membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s compartilhou »%s« com você.",
    "%s shared »%s« with \"%s\"." : "%s compartilhou »%s« com \"%s\".",
    "%s on %s" : "%s em %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou »%2$s« com você.\nVocê já deve ter recebido um e-mail separado com um link para acessar.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou »%2$s« com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
    "Password to access »%1$s« shared to you by %2$s" : "Senha para acessar »%1$s« compartilhado com você por %2$s",
    "Password to access »%s«" : "Senha para acessar »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte senha:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartilhou vários arquivos com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-los.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartilhou vários arquivos com você. Você já deve ter recebido um e-mail separado com um link para acessá-los.",
    "Password to access files shared to you by %1$s" : "Senha para acessar os arquivos compartilhados com você por %1$s",
    "Password to access files" : "Senha para acessar arquivos",
    "%s shared multiple files with \"%s\"." : "%s compartilhou vários arquivos com \"%s\".",
    "%s shared multiple files with you." : "%s compartilhou vários arquivos com você. ",
    "Boot up" : "Inicializar",
    "Nextcloud Initialization" : "Inicialização do Nextcloud",
    "Circles App Initialization" : "Inicialização do Aplicativo Círculos",
    "Fresh installation status" : "Novo status de instalação",
    "Building Local Database" : "Construindo banco de dados local",
    "Testing Basic Team Creation" : "Teste de Criação de uma Equipe Básica",
    "Adding local users and moderators" : "Adicionando usuários locais e moderadores",
    "Show all teams" : "Mostrar todas as equipes",
    "Create a new team" : "Criar uma nova equipe",
    "Files" : "Arquivos",
    "This feature is not available for personal teams" : "Este recurso não está disponível para equipes pessoais",
    "The team is not federated" : "A equipe não é federada",
    "You cannot join this team" : "Você não pode entrar nesta equipe",
    "This member is not a moderator" : "Este membro não é moderador",
    "Insufficient privileges" : "Permissões insuficientes",
    "This member does not exist" : "Este membro não existe",
    "This member is the owner of the team" : "Este membro é o proprietário da equipe",
    "Level cannot be changed for this type of member" : "O nível não pode ser mudado para este tipo de usuário",
    "You are already a member of this team" : "Você já é membro desta equipe",
    "You have been blocked from this team" : "Você foi bloqueado desta equipe",
    "The account is already a member of this team" : "A conta já é membro desta equipe",
    "The account has already been invited into this team" : "A conta já foi convidada para esta equipe",
    "%s (Team owned by %s)" : "%s (Equipe de propriedade de %s)",
    "You are now a member of the Team \"%2$s\"" : "Agora você é um membro da Equipe \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Você foi convidado por %1$s para fazer parte da equipe \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s enviou uma solicitação para ser um membro da Equipe \"%2$s\"",
    "Accept" : "Aceitar",
    "Refuse" : "Recusar",
    "Leave the team" : "Deixar a equipe",
    "%s" : "%s",
    "Personal team" : "Equipe pessoal",
    "%s owned by %s" : "%s propriedade de %s",
    "You have no permission to create a new team" : "Você não tem permissão para criar uma nova equipe",
    "%s shared a file with \"%s\"." : "%s compartilhou um arquivo com \"%s\".",
    "%s shared a file with you." : "%s compartilhou um arquivo com você.",
    "%1$s shared %2$s with %3$s" : "%1$s compartilhou %2$s com %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s compartilhou %2$s com \"%3$s\"",
    "Open %s" : "Abrir %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou algum conteúdo com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-lo.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou algum conteúdo com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
    "Password to access content shared with you by %1$s" : "Senha para acessar o conteúdo compartilhado com você por %1$s",
    "Password to access content" : "Senha para acessar o conteúdo",
    "This item is already shared with this team" : "Este item já está compartilhado com esta equipe",
    "Bring cloud-users closer together." : "Reúna os usuários da nuvem.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "O Equipes permite que as pessoas criem seus próprios grupos de pessoas/colegas/amigos. \nEsses grupos de pessoas podem então ser usados ​​por qualquer outro aplicativo para fins de compartilhamento.",
    "Failed to load teams" : "Falha ao carregar equipes",
    "Try again" : "Tentar novamente",
    "No teams found" : "Nenhuma equipe encontrada",
    "Join or create teams to see them here." : "Junte-se ou crie equipes para vê-las aqui.",
    "Create your first team" : "Crie sua primeira equipe",
    "Loading…" : "Carregando…",
    "More teams" : "Mais equipes",
    "No files in here" : "Nenhum arquivo aqui",
    "No entries found in this folder" : "Sem entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "Shared to Circles" : "Compartilhado com Círculos"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
